/*
 * ds3231.c
 *
 *  Created on: 02-12-2017
 *      Author: MR
 */

#include <avr/io.h>
#include <avr/interrupt.h>
#include <math.h>

#include "ds3231.h"
#include "I2C_TWI/i2c_twi.h"




char days[7][14] = {
"poniedziaek ", "     wtorek  ", "      roda  ", "   czwartek  ", "     pitek  ", "     sobota  ", "   niedziela "
};

uint8_t time; // dla czasu zimowego
//uint8_t time = 1 dla czasu letniego



void DS3231_init( void ) {
	uint8_t ctrl = 0;
	TWI_write_buf( DS3231_ADDR, 0x0e, 1, &ctrl );
}
/////////////////////////////////////////////////////////////////////////////////////////////////////////////
// konwersja liczby dziesitnej na BCD
uint8_t dec2bcd(uint8_t dec) {
return ((dec / 10)<<4) | (dec % 10);
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////
// konwersja liczby BCD na dziesitn
uint8_t bcd2dec(uint8_t bcd) {
    return ((((bcd) >> 4) & 0x0F) * 10) + ((bcd) & 0x0F);
}
/////////////////////////////////////////////////////////////////////////////////////////////////////////////
void DS3231_get_datetime( TDATETIME * dt ) {
	uint8_t i;
	uint8_t buf[7];
	TWI_read_buf( DS3231_ADDR, 0x00, 7, buf );
	for( i=0; i<7; i++ ) dt->bytes[i] = bcd2dec( buf[i] );
}
///////////////////////////////////////////////////////////////////////////////////////////////////////////////
void DS3231_set_time( uint8_t hh, uint8_t mm, uint8_t ss ) {
	uint8_t buf[3];
	buf[0]=dec2bcd(ss);
	buf[1]=dec2bcd(mm);
	buf[2]=dec2bcd(hh);
	TWI_write_buf( DS3231_ADDR, 0x00, 3, buf );
}
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void DS3231_set_date( uint8_t year, uint8_t month, uint8_t day, uint8_t dayofweek ) {
	uint8_t buf[4];
	buf[0]=dayofweek;
	buf[1]=dec2bcd(day);
	buf[2]=dec2bcd(month);
	buf[3]=dec2bcd(year);
	TWI_write_buf( DS3231_ADDR, 0x03, 4, buf );
}
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void DS3231_show_time(TDATETIME *dt){
    // wasna funkcja w zalenoci od uytego wywietlacza
}
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void DS3231_show_date(TDATETIME *dt){
	// wasna funkcja w zalenoci od uytego wywietlacza
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void TIME_CORRECTION_EVENT(TDATETIME * dt){
	if(!time){
		if((dt->ss<2)&&(dt->mm==0)&&(dt->hh==2)){
			if((dt->month==3)&&(dt->day>24)&&(dt->dayofweek==7)){

				time=1;
				DS3231_set_time(3,00,02 );
			}
		}
}
	else
		if(time){
			if((dt->ss<2)&&(dt->mm==0)&&(dt->hh==3)){
				if((dt->month==10)&&(dt->day>24)&&(dt->dayofweek==7)){

					time=0;
					DS3231_set_time(2,00,02 );
				}
			}
		}
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
uint16_t day_of_year(TDATETIME * dt){
    uint16_t n,n1,n2,n3;
    n1 = floor(275 * dt->month / 9);
    n2 = floor((dt->month + 9) / 12);
    n3 = (1 + floor((dt->year - 4 * floor(dt->year / 4) + 2) / 3));
    n = n1 - (n2 * n3) + dt->day - 30;
    dt->next_day = n ;
    return dt->next_day;
}
//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void INT_init(void){
	EIMSK |=(1<<INT0);
	EICRA |=(1<<ISC01);
}


